This function is a simple wrapper around the function from the ggm
package with the same name. The only differences are that the order
argument defaults to TRUE and that it adds a DAG class for
easy plotting. Typically, one would use define_model_set() to
create models for use with the phylopath package.
Arguments
- ...
a sequence of model formulae
- order
logical, defaulting to
TRUE. IfTRUEthe nodes of the DAG are permuted according to the topological order. IfFALSEthe nodes are in the order they first appear in the model formulae (from left to right). For use in thephylopathpackage, this should always be kept toTRUE, but the argument is available to avoid potential problems with masking the function from other packages.
Details
Supply a formulas for the model as arguments. Formulas should be of the
form child ~ parent`` and describe each path in your model. Multiple children of a single parent can be combined into a single formula: child ~ parent1 + parent2. Finally, an isolate (unconnected variable) can be included as being connected to itself: isolate ~ isolate`.